generate_two_samples_at_one_lux: Create two samples of melatonin suppression observations from...

Description Usage Arguments Value

View source: R/experiments.R

Description

Create two samples of melatonin suppression observations from an intervention type experiment

Usage

1
generate_two_samples_at_one_lux(is_between, lux, n, population_df)

Arguments

is_between

a Boolean indicating whether experiment is within or between type

lux

the lux value at which to conduct the comparison

n

number of individuals in sample

population_df

a tibble representing a virtual experiment

Value

a list of two sets of measured melatonin values


ben18785/chronodoseresponse documentation built on Feb. 24, 2022, 4:07 p.m.